@@ -3,18 +3,21 @@ Main interface for ebs service type definitions.
 
 Usage::
 
-    from mypy_boto3.ebs.type_defs import GetSnapshotBlockResponseTypeDef
+    ```python
+    from mypy_boto3_ebs.type_defs import BlockTypeDef
 
-    data: GetSnapshotBlockResponseTypeDef = {...}
+    data: BlockTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
-from typing import IO, List, Union
+from datetime import datetime
+from typing import IO, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -22,23 +25,14 @@ else:
 
 
 __all__ = (
-    "GetSnapshotBlockResponseTypeDef",
-    "ChangedBlockTypeDef",
-    "ListChangedBlocksResponseTypeDef",
     "BlockTypeDef",
+    "ChangedBlockTypeDef",
+    "GetSnapshotBlockResponseTypeDef",
+    "ListChangedBlocksResponseTypeDef",
     "ListSnapshotBlocksResponseTypeDef",
 )
 
-GetSnapshotBlockResponseTypeDef = TypedDict(
-    "GetSnapshotBlockResponseTypeDef",
-    {
-        "DataLength": int,
-        "BlockData": Union[bytes, IO],
-        "Checksum": str,
-        "ChecksumAlgorithm": Literal["SHA256"],
-    },
-    total=False,
-)
+BlockTypeDef = TypedDict("BlockTypeDef", {"BlockIndex": int, "BlockToken": str}, total=False)
 
 ChangedBlockTypeDef = TypedDict(
     "ChangedBlockTypeDef",
@@ -46,10 +40,21 @@ ChangedBlockTypeDef = TypedDict(
     total=False,
 )
 
+GetSnapshotBlockResponseTypeDef = TypedDict(
+    "GetSnapshotBlockResponseTypeDef",
+    {
+        "DataLength": int,
+        "BlockData": IO[bytes],
+        "Checksum": str,
+        "ChecksumAlgorithm": Literal["SHA256"],
+    },
+    total=False,
+)
+
 ListChangedBlocksResponseTypeDef = TypedDict(
     "ListChangedBlocksResponseTypeDef",
     {
-        "ChangedBlocks": List[ChangedBlockTypeDef],
+        "ChangedBlocks": List["ChangedBlockTypeDef"],
         "ExpiryTime": datetime,
         "VolumeSize": int,
         "BlockSize": int,
@@ -58,12 +63,10 @@ ListChangedBlocksResponseTypeDef = TypedDict(
     total=False,
 )
 
-BlockTypeDef = TypedDict("BlockTypeDef", {"BlockIndex": int, "BlockToken": str}, total=False)
-
 ListSnapshotBlocksResponseTypeDef = TypedDict(
     "ListSnapshotBlocksResponseTypeDef",
     {
-        "Blocks": List[BlockTypeDef],
+        "Blocks": List["BlockTypeDef"],
         "ExpiryTime": datetime,
         "VolumeSize": int,
         "BlockSize": int,
